@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import time
-
 import mock
 from oslo_config import cfg
 import six
@@ -51,10 +49,6 @@ class ServerGroupTestBase(test.TestCase,
                         + ['ServerGroupAntiAffinityFilter',
                            'ServerGroupAffinityFilter'])
 
-    # Override servicegroup parameters to make the tests run faster
-    _service_down_time = 10
-    _report_interval = 1
-
     anti_affinity = {'name': 'fake-name-1', 'policies': ['anti-affinity']}
     affinity = {'name': 'fake-name-2', 'policies': ['affinity']}
 
@@ -70,8 +64,6 @@ class ServerGroupTestBase(test.TestCase,
         self.flags(disk_allocation_ratio=9999.0)
         self.flags(weight_classes=self._get_weight_classes(),
                    group='filter_scheduler')
-        self.flags(service_down_time=self._service_down_time)
-        self.flags(report_interval=self._report_interval)
 
         self.useFixture(policy_fixture.RealPolicyFixture())
         self.useFixture(nova_fixtures.NeutronFixture(self))
@@ -144,14 +136,9 @@ class ServerGroupTestV21(ServerGroupTestBase):
         # tree.
         self.stub_out('nova.virt.driver.load_compute_driver',
                       _fake_load_compute_driver)
-        fake.set_nodes(['compute'])
-        self.addCleanup(fake.restore_nodes)
         self.compute = self.start_service('compute', host='compute')
 
         # NOTE(gibi): start a second compute host to be able to test affinity
-        # NOTE(sbauza): Make sure the FakeDriver returns a different nodename
-        # for the second compute node.
-        fake.set_nodes(['host2'])
         self.compute2 = self.start_service('compute', host='host2')
 
     def test_get_no_groups(self):
@@ -371,7 +358,6 @@ class ServerGroupTestV21(ServerGroupTestBase):
 
     def test_migrate_with_anti_affinity(self):
         # Start additional host to test migration with anti-affinity
-        fake.set_nodes(['host3'])
         self.start_service('compute', host='host3')
 
         created_group = self.api.post_server_groups(self.anti_affinity)
@@ -414,19 +400,22 @@ class ServerGroupTestV21(ServerGroupTestBase):
 
         return host
 
+    def _set_forced_down(self, service, forced_down):
+        # Use microversion 2.53 for PUT /os-services/{service_id} force down.
+        with utils.temporary_mutation(self.admin_api, microversion='2.53'):
+            self.admin_api.put_service_force_down(service.service_ref.uuid,
+                                                  forced_down)
+
     def test_evacuate_with_anti_affinity(self):
         created_group = self.api.post_server_groups(self.anti_affinity)
         servers = self._boot_servers_to_group(created_group)
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         # Start additional host to test evacuation
-        fake.set_nodes(['host3'])
         self.start_service('compute', host='host3')
 
         post = {'evacuate': {'onSharedStorage': False}}
@@ -442,18 +431,14 @@ class ServerGroupTestV21(ServerGroupTestBase):
         self.assertNotEqual(evacuated_server['OS-EXT-SRV-ATTR:host'],
                             servers[0]['OS-EXT-SRV-ATTR:host'])
 
-        host.start()
-
     def test_evacuate_with_anti_affinity_no_valid_host(self):
         created_group = self.api.post_server_groups(self.anti_affinity)
         servers = self._boot_servers_to_group(created_group)
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         post = {'evacuate': {'onSharedStorage': False}}
         self.admin_api.post_server_action(servers[1]['id'], post)
@@ -466,18 +451,14 @@ class ServerGroupTestV21(ServerGroupTestBase):
         self.assertEqual(server_after_failed_evac['OS-EXT-SRV-ATTR:host'],
                          servers[1]['OS-EXT-SRV-ATTR:host'])
 
-        host.start()
-
     def test_evacuate_with_affinity_no_valid_host(self):
         created_group = self.api.post_server_groups(self.affinity)
         servers = self._boot_servers_to_group(created_group)
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         post = {'evacuate': {'onSharedStorage': False}}
         self.admin_api.post_server_action(servers[1]['id'], post)
@@ -490,8 +471,6 @@ class ServerGroupTestV21(ServerGroupTestBase):
         self.assertEqual(server_after_failed_evac['OS-EXT-SRV-ATTR:host'],
                          servers[1]['OS-EXT-SRV-ATTR:host'])
 
-        host.start()
-
     def test_soft_affinity_not_supported(self):
         ex = self.assertRaises(client.OpenStackApiException,
                                self.api.post_server_groups,
@@ -617,13 +596,10 @@ class ServerGroupTestV215(ServerGroupTestV21):
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         # Start additional host to test evacuation
-        fake.set_nodes(['host3'])
         compute3 = self.start_service('compute', host='host3')
 
         post = {'evacuate': {}}
@@ -640,7 +616,6 @@ class ServerGroupTestV215(ServerGroupTestV21):
                             servers[0]['OS-EXT-SRV-ATTR:host'])
 
         compute3.kill()
-        host.start()
 
     def test_evacuate_with_anti_affinity_no_valid_host(self):
         created_group = self.api.post_server_groups(self.anti_affinity)
@@ -648,10 +623,8 @@ class ServerGroupTestV215(ServerGroupTestV21):
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         post = {'evacuate': {}}
         self.admin_api.post_server_action(servers[1]['id'], post)
@@ -664,18 +637,14 @@ class ServerGroupTestV215(ServerGroupTestV21):
         self.assertEqual(server_after_failed_evac['OS-EXT-SRV-ATTR:host'],
                          servers[1]['OS-EXT-SRV-ATTR:host'])
 
-        host.start()
-
     def test_evacuate_with_affinity_no_valid_host(self):
         created_group = self.api.post_server_groups(self.affinity)
         servers = self._boot_servers_to_group(created_group)
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         post = {'evacuate': {}}
         self.admin_api.post_server_action(servers[1]['id'], post)
@@ -688,8 +657,6 @@ class ServerGroupTestV215(ServerGroupTestV21):
         self.assertEqual(server_after_failed_evac['OS-EXT-SRV-ATTR:host'],
                          servers[1]['OS-EXT-SRV-ATTR:host'])
 
-        host.start()
-
     def _check_group_format(self, group, created_group):
         self.assertEqual(group['policies'], created_group['policies'])
         self.assertEqual({}, created_group['metadata'])
@@ -818,10 +785,8 @@ class ServerGroupTestV215(ServerGroupTestV21):
 
         host = self._get_compute_service_by_host_name(
             servers[1]['OS-EXT-SRV-ATTR:host'])
-        host.stop()
-        # Need to wait service_down_time amount of seconds to ensure
-        # nova considers the host down
-        time.sleep(self._service_down_time)
+        # Set forced_down on the host to ensure nova considers the host down.
+        self._set_forced_down(host, True)
 
         post = {'evacuate': {}}
         self.admin_api.post_server_action(servers[1]['id'], post)
@@ -834,8 +799,6 @@ class ServerGroupTestV215(ServerGroupTestV21):
         # new host later
         evacuated_server = self.admin_api.get_server(evacuated_server['id'])
 
-        host.start()
-
         return [evacuated_server['OS-EXT-SRV-ATTR:host'],
                 servers[0]['OS-EXT-SRV-ATTR:host']]
 
@@ -906,11 +869,8 @@ class ServerGroupTestMultiCell(ServerGroupTestBase):
     def setUp(self):
         super(ServerGroupTestMultiCell, self).setUp()
         # Start two compute services, one per cell
-        fake.set_nodes(['host1'])
-        self.addCleanup(fake.restore_nodes)
         self.compute1 = self.start_service('compute', host='host1',
                                            cell='cell1')
-        fake.set_nodes(['host2'])
         self.compute2 = self.start_service('compute', host='host2',
                                            cell='cell2')
         # This is needed to find a server that is still booting with multiple
@@ -994,9 +954,7 @@ class TestAntiAffinityLiveMigration(test.TestCase,
         # Start conductor, scheduler and two computes.
         self.start_service('conductor')
         self.start_service('scheduler')
-        self.addCleanup(fake.restore_nodes)
         for host in ('host1', 'host2'):
-            fake.set_nodes([host])
             self.start_service('compute', host=host)
 
     def test_serial_no_valid_host_then_pass_with_third_host(self):
@@ -1058,7 +1016,6 @@ class TestAntiAffinityLiveMigration(test.TestCase,
 
         # Now start up a 3rd compute service and retry the live migration which
         # should work this time.
-        fake.set_nodes(['host3'])
         self.start_service('compute', host='host3')
         self.admin_api.post_server_action(server['id'], body)
         server = self._wait_for_state_change(self.admin_api, server, 'ACTIVE')
