@@ -73,6 +73,9 @@ VIR_DOMAIN_EVENT_STOPPED = 5
 VIR_DOMAIN_EVENT_SHUTDOWN = 6
 VIR_DOMAIN_EVENT_PMSUSPENDED = 7
 
+VIR_DOMAIN_EVENT_SUSPENDED_MIGRATED = 1
+VIR_DOMAIN_EVENT_SUSPENDED_POSTCOPY = 7
+
 VIR_DOMAIN_UNDEFINE_MANAGED_SAVE = 1
 VIR_DOMAIN_UNDEFINE_NVRAM = 4
 
